@@ -1,10 +1,21 @@
 from __future__ import annotations
-from typing import Iterable
+from typing import Iterable, TypeVar
 
 from .constants import FIRST, MIN_TIMES, INCREMENT, SKIP, SLICE_SEP
 from .types import T
 
 
+U = TypeVar('U')
+
+
+def first(
+  items: Iterable[T],
+  default: U | None = None,
+) -> T | U | None:
+  it = iter(items)
+  return next(it, default)
+
+
 # see https://docs.python.org/3/library/itertools.html#itertools.cycle
 def _cycle_times(
   iterable: Iterable[T],
@@ -46,3 +57,14 @@ def _slice_from_str(string: str) -> slice:
   )
 
   return slice(*nums)
+
+
+def _get_window(num: str | int) -> slice:
+  if isinstance(num, str):
+    return _slice_from_str(num)
+
+  elif isinstance(num, int):
+    index: int = num if num <= 0 else num - 1
+    return slice(index, index + 1)
+
+  raise ValueError
