@@ -3,18 +3,19 @@ from typing import Iterable, NamedTuple, Callable, Any, \
     TypeVar, Generic, NoReturn, ParamSpec, Type, Literal, \
     Sequence, Final
 from functools import wraps
-from enum import IntEnum, auto
+from enum import IntEnum
 from dataclasses import dataclass
 
 from more_itertools import peekable
-from strenum import StrEnum
 from unpackable import Unpackable
 
 from .constants import NEW_LINE, NO_RESULT
 
 
-RepeatTimes = Literal['forever', 'inf', 'infinite', 'loop']
-ColumnSeps = Literal['tab', 'newline', 'space']
+RepeatTimes = \
+  Literal['forever', 'inf', 'infinite', 'loop']
+ColumnSeps = \
+  Literal['tab', 'line', 'newline', 'space']
 
 
 FOREVER_OPTS: Final[set[str]] = set(RepeatTimes.__args__)
@@ -95,17 +96,10 @@ class ErrCode(IntEnum):
     return self != ErrCode.none
 
 
-class CmdState(StrEnum):
-  ok: str = auto()
-  err: str = auto()
-  quit: str = auto()
-
-
 @dataclass
 class Result(Generic[T], Unpackable):
   result: T | None = None
   code: ErrCode = ErrCode.none
-  # state: CmdState = CmdState.ok
 
 
 @dataclass
